ad_page_contract {
    Let's administrator become any user.

    @author mobin@mit.edu (Usman Y. Mobin)
    @creation-date 27 Jan 2000

} {
    user_id:naturalnum,notnull
}

